[Asterisk-code-review] spelling: appear (asterisk[master])

Josh Soref asteriskteam at digium.com
Sun Nov 7 00:03:40 CDT 2021


Josh Soref has uploaded this change for review. ( https://gerrit.asterisk.org/c/asterisk/+/16731 )


Change subject: spelling: appear
......................................................................

spelling: appear

Change-Id: I17cc7d4f30092a2d7b2f71c0a506b3c1c4b97165
---
M channels/chan_unistim.c
M main/channel.c
M main/core_local.c
3 files changed, 4 insertions(+), 4 deletions(-)



  git pull ssh://gerrit.asterisk.org:29418/asterisk refs/changes/31/16731/1

diff --git a/main/channel.c b/main/channel.c
index e7e9d9d..d601595 100644
--- a/main/channel.c
+++ b/main/channel.c
@@ -6919,7 +6919,7 @@
 	 */
 	ao2_lock(channels);
 
-	/* Bump the refs to ensure that they won't dissapear on us. */
+	/* Bump the refs to ensure that they won't dissappear on us. */
 	ast_channel_ref(original);
 	ast_channel_ref(clonechan);
 
diff --git a/main/core_local.c b/main/core_local.c
index d4e4001..baa3e1f 100644
--- a/main/core_local.c
+++ b/main/core_local.c
@@ -883,7 +883,7 @@
 	 *
 	 * This is a silly default because it represents state held by
 	 * the local channels.  Unless local channel optimization is
-	 * disabled, the state will dissapear when the local channels
+	 * disabled, the state will dissappear when the local channels
 	 * optimize out.
 	 */
 	ast_set_flag(&pvt->base, AST_UNREAL_MOH_INTERCEPT);

diff --git a/channels/chan_unistim.c b/channels/chan_unistim.c
index 5b4a97f..0d28d47 100644
--- a/channels/chan_unistim.c
+++ b/channels/chan_unistim.c
@@ -2181,7 +2181,7 @@
 		AST_LIST_LOCK(&pte->device->subs);
 		AST_LIST_TRAVERSE_SAFE_BEGIN(&pte->device->subs, sub, list) {
 			if (sub) {
-				ast_log(LOG_ERROR, "Subchannel lost sice reboot. Hanged channel may apear!\n");
+				ast_log(LOG_ERROR, "Subchannel lost sice reboot. Hanged channel may appear!\n");
 				AST_LIST_REMOVE_CURRENT(list);
 				ast_free(sub);
 			}
@@ -4889,7 +4889,7 @@
 	}
 	session->state = STATE_RINGING;
 	send_callerid_screen(session, sub);
-	if (ast_strlen_zero(ast_channel_call_forward(ast))) { /* Send ring only if no call forward, otherwise short ring will apear */
+	if (ast_strlen_zero(ast_channel_call_forward(ast))) { /* Send ring only if no call forward, otherwise short ring will appear */
 		send_text(TEXT_LINE2, TEXT_NORMAL, session, ustmtext("is calling you.", session));
 		send_text_status(session, ustmtext("Accept        Ignore Hangup", session));
 
-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/16731
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: I17cc7d4f30092a2d7b2f71c0a506b3c1c4b97165
Gerrit-Change-Number: 16731
Gerrit-PatchSet: 1
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-CC: Friendly Automation
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211107/c4cf7d00/attachment-0001.html>


More information about the asterisk-code-review mailing list